package devoir03.modele;

import java.util.List;

/**
 * Cette interface représente l'index (vu en lecture). Vous devrez l'implanter,
 * mais évidemment aussi ajouter les méthodes nécessaires pour pouvoir remplir
 * l'index.
 * 
 * @author rosmord
 * 
 */
public interface IndexInterface {
	/**
	 * Renvoie la liste des documents qui contiennent un mot donné.
	 * <p>
	 * Si le mot n'est pas trouvé, la méthode doit renvoyer la liste vide.
	 * 
	 * @param mot
	 * @return une liste de documents.
	 */
	List<UnDocument> get(String mot);

	/**
	 * Renvoie la liste des mots qui apparaissent dans l'index.
	 * 
	 * @return
	 */
	List<String> getMotsIndexes();

	/**
	 * Indexe un document.
	 * <p>
	 * Pour l'index : on indexe tous les <em>mots</em> du texte (pas du titre).
	 * <p>
	 * Un mot est défini comme une <em>suite de lettres</em> au sens de
	 * {@link Character#isLetter(char)}.
	 * <p>
	 * Par exemple, dans la chaîne suivante "abc33deux et hop!", on a les mots
	 * "abc", "deux", "et" et "hop".
	 * <p>
	 * Post-condition(s) :
	 * <ol>
	 * <li>les mots déjà indexés restent indexés (on ne doit pas effacer les
	 * valeurs déjà présentes !!!)
	 * <li>après indexation, tout mot du contenu du document est dans la liste
	 * des mots indexés renvoyée par {@link #getMotsIndexes()}.
	 * <li>si un mot apparaît dans le document d : après indexation de d,
	 * l'appel à la méthode {@link #get(String)} doit renvoyer une liste qui
	 * contient le document d.
	 * </ol>
	 * 
	 * <p>
	 * Remarque : il est assez probable que nos tests vérifient que les
	 * post-conditions sont respectées.
	 * 
	 * @param document
	 */
	void indexerDocument(UnDocument document);

	/**
	 * Efface le contenu de l'index.
	 * <p>
	 * Post condition : l'index est vide, {@link #getMotsIndexes()} renvoie la
	 * liste vide, et {@link #get(String)} renvoie la liste vide pour tout mot.
	 * 
	 */

	void effacer();

}
